Thread Models
=============

Classes for representing conversations.

Thread
------

.. autoclass:: fbchat_muqit.Thread
   :members:
   :undoc-members:
   :show-inheritance:

ThreadType
----------

.. autoclass:: fbchat_muqit.ThreadType
   :members:
   :undoc-members:
   :show-inheritance:

ThreadFolder
------------

.. autoclass:: fbchat_muqit.ThreadFolder
   :members:
   :undoc-members:
   :show-inheritance:
